@@ -253,6 +253,12 @@ class IMAPServer(object):
             try:
                 response = urllib.urlopen(
                     self.oauth2_request_url, urllib.urlencode(params)).read()
+            except Exception as e:
+                try:
+                    msg = "%s (configuration is: %s)"% (e, str(params))
+                except Exception as eparams:
+                    msg = "%s [cannot display configuration: %s]"% (e, eparams)
+                six.reraise(type(e), type(e)(msg), exc_info()[2])
             finally:
                 socket.socket = original_socket
 
@@ -378,6 +384,10 @@ class IMAPServer(object):
         warnings for failed methods are to be produced in the
         respective except blocks."""
 
+        # Stack stores pairs of (method name, exception)
+        exc_stack = []
+        tried_to_authn = False
+        tried_tls = False
         # Authentication routines, hash keyed by method name
         # with value that is a tuple with
         # - authentication function,
@@ -385,24 +395,15 @@ class IMAPServer(object):
         # - check IMAP capability flag.
         auth_methods = {
           "GSSAPI": (self.__authn_gssapi, False, True),
-          "CRAM-MD5": (self.__authn_cram_md5, True, True),
           "XOAUTH2": (self.__authn_xoauth2, True, True),
+          "CRAM-MD5": (self.__authn_cram_md5, True, True),
           "PLAIN": (self.__authn_plain, True, True),
           "LOGIN": (self.__authn_login, True, False),
         }
-        # Stack stores pairs of (method name, exception)
-        exc_stack = []
-        tried_to_authn = False
-        tried_tls = False
-        mechs = self.authmechs
 
-        # GSSAPI must be tried first: we will probably go TLS after it
-        # and GSSAPI mustn't be tunneled over TLS.
-        if "GSSAPI" in mechs:
-            mechs.remove("GSSAPI")
-            mechs.insert(0, "GSSAPI")
-
-        for m in mechs:
+        # GSSAPI is tried first by default: we will probably go TLS after it and
+        # GSSAPI mustn't be tunneled over TLS.
+        for m in self.authmechs:
             if m not in auth_methods:
                 raise Exception("Bad authentication method %s, "
                   "please, file OfflineIMAP bug" % m)
@@ -431,17 +432,12 @@ class IMAPServer(object):
                 exc_stack.append((m, e))
 
         if len(exc_stack):
-            msg = "\n\t".join(map(
-              lambda x: ": ".join((x[0], str(x[1]))),
-              exc_stack
-            ))
+            msg = "\n\t".join([": ".join((x[0], str(x[1]))) for x in exc_stack])
             raise OfflineImapError("All authentication types "
               "failed:\n\t%s"% msg, OfflineImapError.ERROR.REPO)
 
         if not tried_to_authn:
-            methods = ", ".join(map(
-              lambda x: x[5:], [x for x in imapobj.capabilities if x[0:5] == "AUTH="]
-            ))
+            methods = ", ".join([x[5:] for x in [x for x in imapobj.capabilities if x[0:5] == "AUTH="]])
             raise OfflineImapError(u"Repository %s: no supported "
               "authentication mechanisms found; configured %s, "
               "server advertises %s"% (self.repos,
@@ -489,7 +485,8 @@ class IMAPServer(object):
             while success is not True:
                 # Generate a new connection.
                 if self.tunnel:
-                    self.ui.connecting('tunnel', self.tunnel)
+                    self.ui.connecting(
+                        self.repos.getname(), 'tunnel', self.tunnel)
                     imapobj = imaplibutil.IMAP4_Tunnel(
                         self.tunnel,
                         timeout=socket.getdefaulttimeout(),
@@ -497,7 +494,8 @@ class IMAPServer(object):
                         )
                     success = True
                 elif self.usessl:
-                    self.ui.connecting(self.hostname, self.port)
+                    self.ui.connecting(
+                        self.repos.getname(), self.hostname, self.port)
                     imapobj = imaplibutil.WrappedIMAP4_SSL(
                         host=self.hostname,
                         port=self.port,
@@ -513,7 +511,8 @@ class IMAPServer(object):
                         af=self.af,
                         )
                 else:
-                    self.ui.connecting(self.hostname, self.port)
+                    self.ui.connecting(
+                        self.repos.getname(), self.hostname, self.port)
                     imapobj = imaplibutil.WrappedIMAP4(
                         self.hostname, self.port,
                         timeout=socket.getdefaulttimeout(),
